==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CASEMANAGEMENTTASKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CASEMANAGEMENTTASKID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CASEMANAGEMENTTASKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASEMANAGEMENTTASKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CASEMANAGEMENTTASKID_Type", propOrder = {
    "casemanagementtaskcode",
    "description"
})
public class CASEMANAGEMENTTASKID_Type {

    @XmlElement(name = "CASEMANAGEMENTTASKCODE", required = true)
    protected String casemanagementtaskcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété casemanagementtaskcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCASEMANAGEMENTTASKCODE() {
        return casemanagementtaskcode;
    }

    /**
     * Définit la valeur de la propriété casemanagementtaskcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCASEMANAGEMENTTASKCODE(String value) {
        this.casemanagementtaskcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CASEMANAGEMENTTASKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CASEMANAGEMENTTASKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CASEMANAGEMENTTASKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASEMANAGEMENTTASKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CASEMANAGEMENTTASKID_Type", propOrder = {
    "casemanagementtaskcode",
    "description"
})
public class CASEMANAGEMENTTASKID_Type {

    @XmlElement(name = "CASEMANAGEMENTTASKCODE", required = true)
    protected String casemanagementtaskcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the casemanagementtaskcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCASEMANAGEMENTTASKCODE() {
        return casemanagementtaskcode;
    }

    /**
     * Sets the value of the casemanagementtaskcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCASEMANAGEMENTTASKCODE(String value) {
        this.casemanagementtaskcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
